#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from onf_website.shared.common.skin.interfaces import ISharedContentSpecifitiesPortletSettings
from pyams_form.form import AJAXEditForm
from pyams_form.interfaces.form import IInnerTabForm
from pyams_pagelet.interfaces import IPagelet
from pyams_pagelet.pagelet import pagelet_config
from pyams_portal.interfaces import IPortletPreviewer
from pyams_portal.portlet import PortletPreviewer
from pyams_portal.zmi.portlet import PortletSettingsEditor, PortletSettingsPropertiesEditor
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.interfaces import VIEW_SYSTEM_PERMISSION


@pagelet_config(name='properties.html', context=ISharedContentSpecifitiesPortletSettings, layer=IPyAMSLayer,
                permission=VIEW_SYSTEM_PERMISSION)
class SharedContentSpecificitiesPortletSettingsEditor(PortletSettingsEditor):
    """Shared content specificities portlet settings editor"""

    settings = ISharedContentSpecifitiesPortletSettings


@adapter_config(name='properties', context=(Interface, IPyAMSLayer, SharedContentSpecificitiesPortletSettingsEditor),
                provides=IInnerTabForm)
class SharedContentSpecificitiesPortletSettingsPropertiesEditor(PortletSettingsPropertiesEditor):
    """Shared content specificities portlet settings properties editor"""


@adapter_config(name='properties.json', context=(ISharedContentSpecifitiesPortletSettings, IPyAMSLayer),
                provides=IPagelet)
class SharedContentSpecificitiesPortletAJAXEditor(AJAXEditForm, SharedContentSpecificitiesPortletSettingsEditor):
    """Shared content specificities portlet settings editor, JSON renderer"""


@adapter_config(context=(Interface, IPyAMSLayer, Interface, ISharedContentSpecifitiesPortletSettings),
                provides=IPortletPreviewer)
@template_config(template='templates/specificities-preview.pt', layer=IPyAMSLayer)
class SharedContentSpecificitiesPortletPreviewer(PortletPreviewer):
    """Shared content specificities portlet previewer"""
