#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.component.hearing.interfaces import IHearingInfo
from onf_website.skin.public.layer import IONFBaseLayer
from pyams_skin.interfaces.viewlet import IBreadcrumbItem
from pyams_utils.interfaces.url import DISPLAY_CONTEXT

# import packages
from pyams_skin.viewlet.breadcrumb import BreadcrumbsContentProvider
from pyams_template.template import template_config
from pyams_viewlet.viewlet import contentprovider_config
from pyramid.location import lineage
from zope.interface import Interface


@contentprovider_config(name='pyams.breadcrumbs', layer=IONFBaseLayer, view=Interface)
@template_config(template='breadcrumbs.pt', layer=IONFBaseLayer)
class ONFBreadcrumbsContentProvider(BreadcrumbsContentProvider):
    """ONF breadcrumbs content provider"""

    @property
    def items(self):
        source = None
        registry = self.request.registry
        hearing = IHearingInfo(self.context, None)
        if hearing is not None:
            source = hearing.get_source_folder()
            if source is None:
                source = hearing.get_source_site()
        if source is None:
            source = self.request.annotations.get(DISPLAY_CONTEXT)
            if source is None:
                source = self.request.context
        if source is not None:
            for context in reversed(tuple(lineage(source))):
                item = registry.queryMultiAdapter((context, self.request, self.view), IBreadcrumbItem)
                if item is None:
                    item = registry.queryMultiAdapter((context, self.request), IBreadcrumbItem)
                    if item is None:
                        item = registry.queryAdapter(context, IBreadcrumbItem)
                if item is not None:
                    yield item
